==> PathOfBuildingCommunity-Portable-2.7.0.zip: Data/StatDescriptions/brand_skill_stat_descriptions.lua <==
return {
	[1]={
		stats={
			[1]="base_number_of_sigils_allowed_per_target"
		}
	},
	[2]={
		lang={
			English={
				[1]={
					limit={
						[1]={
							[1]=1,
							[2]="#"
						}
					},
					text="{0}% chance for Brands to Attach to a new Enemy each time they Activate"
				}
			}
		},
		name="armageddon_brand_reattach_each_activation_chance",
		stats={
			[1]="armageddon_brand_brands_attach_to_new_enemy_each_activation_%_chance"
		}
	},
	[3]={
		lang={
			English={
				[1]={
					[1]={
						k="milliseconds_to_seconds_2dp",
						v=1
					},
					limit={
						[1]={
							[1]="#",
							[2]="#"
						}
					},
					text="Can be Detached for a total Duration of {0} seconds"
				}
			}
		},
		name="base_secondary_duration_identifier",
		stats={
			[1]="base_secondary_skill_effect_duration"
		}
	},
	[4]={
		lang={
			English={
				[1]={
					[1]={
						k="milliseconds_to_seconds_2dp",
						v=1
					},
					limit={
						[1]={
							[1]="#",
							[2]="#"
						},
						[2]={
							[1]="#",
							[2]="#"
						}
					},
					text="Can be Attached for a total Duration of {0} seconds"
				}
			}
		},
		name="base_duration_identifier",
		stats={
			[1]="base_skill_effect_duration",
			[2]="quality_display_base_duration_is_quality"
		}
	},
	[5]={
		lang={
			English={
				[1]={
					[1]={
						k="milliseconds_to_seconds_2dp",
						v=1
					},
					limit={
						[1]={
							[1]="#",
							[2]="#"
						}
					},
					text="Base Debuff Duration is {0} seconds"
				}
			}
		},
		name="base_tertiary_duration_identifier",
		stats={
			[1]="base_tertiary_skill_effect_duration"
		}
	},
	[6]={
		lang={
			English={
				[1]={
					limit={
						[1]={
							[1]=1,
							[2]=1
						}
					},
					text="Can have {0} Brand Attached to an Enemy"
				},
				[2]={
					limit={
						[1]={
							[1]=2,
							[2]="#"
						}
					},
					text="Can have {0} Brands Attached to an Enemy"
				}
			}
		},
		name="brand_target_limit",
		stats={
			[1]="brands_per_target_limit"
		}
	},
	[7]={
		lang={
			English={
				[1]={
					limit={
						[1]={
							[1]=1,
							[2]=1
						}
					},
					text="Sends beam to the Branded Enemy"
				},
				[2]={
					limit={
						[1]={
							[1]=2,
							[2]="#"
						}
					},
					text="Sends beams to {0} Enemies, including the Branded Enemy"
				}
			}
		},
		name="storm_brand_beam_num",
		stats={
			[1]="conduit_sigil_number_of_beam_targets"
		}
	},
	[8]={
		lang={
			English={
				[1]={
					[1]={
						k="milliseconds_to_seconds_2dp",
						v=1
					},
					limit={
						[1]={
							[1]=1,
							[2]="#"
						}
					},
					text="Can be Detached for a total Duration of {0} seconds"
				}
			}
		},
		name="secondary_skill_duration",
		stats={
			[1]="secondary_skill_effect_duration"
		}
	},
	[9]={
		lang={
			English={
				[1]={
					limit={
						[1]={
							[1]=1,
							[2]="#"
						}
					},
					text="Deals {0}% more Damage to Branded Enemy"
				},
				[2]={
					[1]={
						k="negate",
						v=1
					},
					limit={
						[1]={
							[1]="#",
							[2]=-1
						}
					},
					text="Deals {0}% less Damage to Branded Enemy"
				}
			}
		},
		name="sigil_attached_target_damage_final",
		stats={
			[1]="sigil_attached_target_damage_+%_final"
		}
	},
	[10]={
		lang={
			English={
				[1]={
					[1]={
						k="milliseconds_to_seconds_2dp",
						v=1
					},
					limit={
						[1]={
							[1]=1000,
							[2]=1000
						}
					},
					text="Activates every {0} second while Attached"
				},
				[2]={
					[1]={
						k="milliseconds_to_seconds_2dp",
						v=1
					},
					limit={
						[1]={
							[1]="#",
							[2]="#"
						}
					},
					text="Activates every {0} seconds while Attached"
				}
			}
		},
		name="sigil_activate_frequency",
		stats={
			[1]="sigil_repeat_frequency_ms"
		}
	},
	[11]={
		lang={
			English={
				[1]={
					[1]={
						k="milliseconds_to_seconds_2dp",
						v=1
					},
					limit={
						[1]={
							[1]=1,
							[2]="#"
						}
					},
					text="Can be Attached for a total Duration of {0} seconds"
				}
			}
		},
		name="skill_duration",
		stats={
			[1]="skill_effect_duration"
		}
	},
	[12]={
		lang={
			English={
				[1]={
					[1]={
						k="milliseconds_to_seconds_2dp",
						v=1
					},
					limit={
						[1]={
							[1]=1,
							[2]="#"
						}
					},
					text="Debuff Lasts {0} seconds"
				}
			}
		},
		name="tertiary_buff_duration",
		stats={
			[1]="tertiary_buff_effect_duration"
		}
	},
	["armageddon_brand_brands_attach_to_new_enemy_each_activation_%_chance"]=2,
	["base_number_of_sigils_allowed_per_target"]=1,
	["base_secondary_skill_effect_duration"]=3,
	["base_skill_effect_duration"]=4,
	["base_tertiary_skill_effect_duration"]=5,
	["brands_per_target_limit"]=6,
	["conduit_sigil_number_of_beam_targets"]=7,
	parent="skill_stat_descriptions",
	["quality_display_base_duration_is_quality"]=4,
	["secondary_skill_effect_duration"]=8,
	["sigil_attached_target_damage_+%_final"]=9,
	["sigil_repeat_frequency_ms"]=10,
	["skill_effect_duration"]=11,
	["tertiary_buff_effect_duration"]=12
}

==> PathOfBuildingCommunity-Portable-2.14.0.zip: Data/StatDescriptions/brand_skill_stat_descriptions.lua <==
return {
	[1]={
		stats={
			[1]="base_number_of_sigils_allowed_per_target"
		}
	},
	[2]={
		lang={
			English={
				[1]={
					limit={
						[1]={
							[1]=1,
							[2]="#"
						}
					},
					text="{0}% chance for Brands to Attach to a new Enemy each time they Activate"
				}
			}
		},
		name="armageddon_brand_reattach_each_activation_chance",
		stats={
			[1]="armageddon_brand_brands_attach_to_new_enemy_each_activation_%_chance"
		}
	},
	[3]={
		lang={
			English={
				[1]={
					[1]={
						k="milliseconds_to_seconds_2dp",
						v=1
					},
					limit={
						[1]={
							[1]="#",
							[2]="#"
						}
					},
					text="Can be Detached for a total Duration of {0} seconds"
				}
			}
		},
		name="base_secondary_duration_identifier",
		stats={
			[1]="base_secondary_skill_effect_duration"
		}
	},
	[4]={
		lang={
			English={
				[1]={
					[1]={
						k="milliseconds_to_seconds_2dp",
						v=1
					},
					limit={
						[1]={
							[1]="#",
							[2]="#"
						},
						[2]={
							[1]="#",
							[2]="#"
						}
					},
					text="Can be Attached for a total Duration of {0} seconds"
				}
			}
		},
		name="base_duration_identifier",
		stats={
			[1]="base_skill_effect_duration",
			[2]="quality_display_base_duration_is_quality"
		}
	},
	[5]={
		lang={
			English={
				[1]={
					[1]={
						k="milliseconds_to_seconds_2dp",
						v=1
					},
					limit={
						[1]={
							[1]="#",
							[2]="#"
						}
					},
					text="Base Debuff Duration is {0} seconds"
				}
			}
		},
		name="base_tertiary_duration_identifier",
		stats={
			[1]="base_tertiary_skill_effect_duration"
		}
	},
	[6]={
		lang={
			English={
				[1]={
					limit={
						[1]={
							[1]=1,
							[2]=1
						}
					},
					text="Can have {0} Brand Attached to an Enemy"
				},
				[2]={
					limit={
						[1]={
							[1]=2,
							[2]="#"
						}
					},
					text="Can have {0} Brands Attached to an Enemy"
				}
			}
		},
		name="brand_target_limit",
		stats={
			[1]="brands_per_target_limit"
		}
	},
	[7]={
		lang={
			English={
				[1]={
					limit={
						[1]={
							[1]=1,
							[2]=1
						}
					},
					text="Sends beam to the Branded Enemy"
				},
				[2]={
					limit={
						[1]={
							[1]=2,
							[2]="#"
						}
					},
					text="Sends beams to {0} Enemies, including the Branded Enemy"
				}
			}
		},
		name="storm_brand_beam_num",
		stats={
			[1]="conduit_sigil_number_of_beam_targets"
		}
	},
	[8]={
		lang={
			English={
				[1]={
					[1]={
						k="milliseconds_to_seconds_2dp",
						v=1
					},
					limit={
						[1]={
							[1]=1,
							[2]="#"
						}
					},
					text="Can be Detached for a total Duration of {0} seconds"
				}
			}
		},
		name="secondary_skill_duration",
		stats={
			[1]="secondary_skill_effect_duration"
		}
	},
	[9]={
		lang={
			English={
				[1]={
					limit={
						[1]={
							[1]=1,
							[2]="#"
						}
					},
					text="Deals {0}% more Damage with Hits against Branded Enemy"
				},
				[2]={
					[1]={
						k="negate",
						v=1
					},
					limit={
						[1]={
							[1]="#",
							[2]=-1
						}
					},
					text="Deals {0}% less Damage with Hits against Branded Enemy"
				}
			}
		},
		name="sigil_attached_target_damage_final",
		stats={
			[1]="sigil_attached_target_hit_damage_+%_final"
		}
	},
	[10]={
		lang={
			English={
				[1]={
					[1]={
						k="milliseconds_to_seconds_2dp",
						v=1
					},
					limit={
						[1]={
							[1]=1000,
							[2]=1000
						}
					},
					text="Activates every {0} second while Attached"
				},
				[2]={
					[1]={
						k="milliseconds_to_seconds_2dp",
						v=1
					},
					limit={
						[1]={
							[1]="#",
							[2]="#"
						}
					},
					text="Activates every {0} seconds while Attached"
				}
			}
		},
		name="sigil_activate_frequency",
		stats={
			[1]="sigil_repeat_frequency_ms"
		}
	},
	[11]={
		lang={
			English={
				[1]={
					[1]={
						k="milliseconds_to_seconds_2dp",
						v=1
					},
					limit={
						[1]={
							[1]=1,
							[2]="#"
						}
					},
					text="Can be Attached for a total Duration of {0} seconds"
				}
			}
		},
		name="skill_duration",
		stats={
			[1]="skill_effect_duration"
		}
	},
	[12]={
		lang={
			English={
				[1]={
					[1]={
						k="milliseconds_to_seconds_2dp",
						v=1
					},
					limit={
						[1]={
							[1]=1,
							[2]="#"
						}
					},
					text="Debuff Lasts {0} seconds"
				}
			}
		},
		name="tertiary_buff_duration",
		stats={
			[1]="tertiary_buff_effect_duration"
		}
	},
	["armageddon_brand_brands_attach_to_new_enemy_each_activation_%_chance"]=2,
	["base_number_of_sigils_allowed_per_target"]=1,
	["base_secondary_skill_effect_duration"]=3,
	["base_skill_effect_duration"]=4,
	["base_tertiary_skill_effect_duration"]=5,
	["brands_per_target_limit"]=6,
	["conduit_sigil_number_of_beam_targets"]=7,
	parent="skill_stat_descriptions",
	["quality_display_base_duration_is_quality"]=4,
	["secondary_skill_effect_duration"]=8,
	["sigil_attached_target_hit_damage_+%_final"]=9,
	["sigil_repeat_frequency_ms"]=10,
	["skill_effect_duration"]=11,
	["tertiary_buff_effect_duration"]=12
}
